pub enum Row {
Integer(BTreeMap<i64, i32>),
Text(BTreeMap<i64, String>),
Real(BTreeMap<i64, f32>),
Bool(BTreeMap<i64, bool>),
None,
}Expand description
The schema for each SQL row in every table is represented in memory by following structure
This is an enum representing each of the available types organized in a BTreeMap data structure, using the ROWID and key and each corresponding type as value
Variants
Integer(BTreeMap<i64, i32>)
Text(BTreeMap<i64, String>)
Real(BTreeMap<i64, f32>)
Bool(BTreeMap<i64, bool>)
None
Implementations