pub struct CreateQuery {
pub table_name: String,
pub columns: Vec<ParsedColumn>,
pub if_not_exists: bool,
}Expand description
The following structure represents a CREATE TABLE query already parsed
and broken down into name and a Vector of ParsedColumn metadata
Fields
table_name: Stringname of table after parking and tokenizing of query
columns: Vec<ParsedColumn>Vector of ParsedColumn type with column metadata information
if_not_exists: booltrue when the statement was CREATE TABLE IF NOT EXISTS ….
When set, re-creating an existing table is a no-op rather than
an error — matching CREATE INDEX IF NOT EXISTS and SQLite.
Implementations
Sourceimpl CreateQuery
impl CreateQuery
pub fn new(statement: &Statement) -> Result<CreateQuery>