Module create

Module create 

Structs

CreateQuery
The following structure represents a CREATE TABLE query already parsed and broken down into name and a Vector of ParsedColumn metadata
ParsedColumn
The schema for each SQL column in every table is represented by the following structure after parsed and tokenized