pub struct CreateQuery {
pub table_name: String,
pub columns: Vec<ParsedColumn>,
}Expand description
The following structure represents a CREATE TABLE query already parsed
and broken down into name and a Vector of ParsedColumn metadata
Fields
table_name: Stringname of table after parking and tokenizing of query
columns: Vec<ParsedColumn>Vector of ParsedColumn type with column metadata information
Implementations
Sourceimpl CreateQuery
impl CreateQuery
pub fn new(statement: &Statement) -> Result<CreateQuery>