pub struct ParsedColumn {
pub name: String,
pub datatype: String,
pub is_pk: bool,
pub not_null: bool,
pub is_unique: bool,
pub default: Option<Value>,
}Expand description
The schema for each SQL column in every table is represented by the following structure after parsed and tokenized
Fields
name: StringName of the column
datatype: StringDatatype of the column in String format
is_pk: boolValue representing if column is PRIMARY KEY
not_null: boolValue representing if column was declared with the NOT NULL Constraint
is_unique: boolValue representing if column was declared with the UNIQUE Constraint
default: Option<Value>Literal value to use when this column is omitted from an INSERT.
Restricted to literal expressions (integer, real, text, bool, NULL);
non-literal DEFAULT expressions are rejected at CREATE TABLE time.